aboutsummaryrefslogtreecommitdiff
path: root/gcc/langhooks.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/langhooks.h')
-rw-r--r--gcc/langhooks.h24
1 files changed, 17 insertions, 7 deletions
diff --git a/gcc/langhooks.h b/gcc/langhooks.h
index 98532521e5e..43749a24e88 100644
--- a/gcc/langhooks.h
+++ b/gcc/langhooks.h
@@ -183,6 +183,15 @@ struct lang_hooks_for_decls
/* True if this decl may be called via a sibcall. */
bool (*ok_for_sibcall) (tree);
+
+ /* Return the COMDAT group into which this DECL should be placed.
+ It is known that the DECL belongs in *some* COMDAT group when
+ this hook is called. The return value will be used immediately,
+ but not explicitly deallocated, so implementations should not use
+ xmalloc to allocate the string returned. (Typically, the return
+ value will be the string already stored in an
+ IDENTIFIER_NODE.) */
+ const char * (*comdat_group) (tree);
};
/* Language-specific hooks. See langhooks-def.h for defaults. */
@@ -196,9 +205,10 @@ struct lang_hooks
identifier nodes long enough for the language-specific slots. */
size_t identifier_size;
- /* Determines the size of any language-specific 'x' or 'c' nodes.
- Since it is called from make_node, the only information available
- is the tree code. Expected to abort on unrecognized codes. */
+ /* Determines the size of any language-specific tcc_constant or
+ tcc_exceptional nodes. Since it is called from make_node, the
+ only information available is the tree code. Expected to abort
+ on unrecognized codes. */
size_t (*tree_size) (enum tree_code);
/* The first callback made to the front end, for simple
@@ -329,12 +339,12 @@ struct lang_hooks
this hook. It should output to stderr. */
void (*print_statistics) (void);
- /* Called by print_tree when there is a tree of class 'x' that it
- doesn't know how to display. */
+ /* Called by print_tree when there is a tree of class tcc_exceptional
+ that it doesn't know how to display. */
lang_print_tree_hook print_xnode;
- /* Called to print language-dependent parts of a class 'd', class
- 't', and IDENTIFIER_NODE nodes. */
+ /* Called to print language-dependent parts of tcc_decl, tcc_type,
+ and IDENTIFIER_NODE nodes. */
lang_print_tree_hook print_decl;
lang_print_tree_hook print_type;
lang_print_tree_hook print_identifier;